@@ -158,6 +158,9 @@ protected:
     {}
 
 public:
+    virtual ~Arg()
+    {}
+
     /**
       Indicate that the argument shouldn't be shown in help text.
 
@@ -749,13 +752,9 @@ public:
     */
     virtual void setValue(const std::string& s)
     {
-        if (s.size() && s[0] == '-')
-        {
-            throw arg_val_error("Argument '" + m_longname +
-                "' needs a value and none was provided.");
-        }
-        m_rawVal = s;
         T var;
+
+        m_rawVal = s;
         if (!Utils::fromString(s, var))
         {
             std::string error(m_error);
@@ -866,11 +865,9 @@ public:
         for (auto& ts : slist)
             Utils::trim(ts);
 
-        if ((s.size() && s[0] == '-') || slist.empty())
-        {
+        if (slist.empty())
             throw arg_val_error("Missing value for argument '" + m_longname +
                 "'.");
-        }
         m_rawVal = s;
         if (!m_set)
             m_var.clear();
@@ -1070,8 +1067,8 @@ public:
 
     /**
       Parse a command line as specified by its argument vector.  No validation
-      occurs and no exceptions are raised, but assignments are made
-      to bound variables where possible.
+      occurs and only argument value exceptions are raised,
+      but assignments are made to bound variables where possible.
 
       \param s  List of strings that constitute the argument list.
     */
@@ -1131,7 +1128,7 @@ public:
 
       \param s  List of strings that constitute the argument list.
     */
-    void parse(std::vector<std::string>& s)
+    void parse(const std::vector<std::string>& s)
     {
         validate();
         ArgValList vals(s);
@@ -1157,6 +1154,26 @@ public:
             Arg *arg = ai->get();
             arg->assignPositional(vals);
         }
+        //NOTE - Perhaps we should error here if there are still
+        //  unconsumed arguments.
+    }
+
+    /**
+      Add a synonym for an argument.
+
+      \param name  Longname of existing arugment.
+      \param synonym  Synonym for argument.
+    */
+    void addSynonym(const std::string& name, const std::string& synonym)
+    {
+        Arg *arg = findLongArg(name);
+        if (!arg)
+            throw arg_error("Can't set synonym for argument '" + name + "'. "
+                "Argument doesn't exist.");
+        if (synonym.empty())
+            throw arg_error("Invalid (empty) synonym for argument '" +
+                name + "'.");
+        addLongArg(synonym, arg);
     }
 
     /**
@@ -1217,7 +1234,7 @@ public:
             std::string nameDescrip = a->nameDescrip();
 
             info.push_back(std::make_pair(nameDescrip, a->description()));
-            namelen = std::max(namelen, nameDescrip.size());
+            namelen = (std::max)(namelen, nameDescrip.size());
         }
         size_t secondIndent = indent + 4;
         int postNameSpacing = 2;
@@ -1312,6 +1329,7 @@ public:
         }
         out << "]";
     }
+
 private:
     /*
       Split an argument name into longname and shortname.
@@ -1463,7 +1481,7 @@ private:
                 {
                     throw arg_error("Value '" + value +
                         "' provided for argument '" + name +
-                        "' when none is expected.");
+                        "' when 'true' or 'false' is expected.");
                 }
             }
             else
